@@ -7,13 +7,19 @@ app.controller("megaMenuCtrl", ['$rootScope', '$scope', 'httpEndPointService','r
 function($rootScope, $scope, httpEndPointService, requestRoutingService) {
 	var MENU_URL="utils/megamenu/helper/menu.json";
 	var versionInfo = requestRoutingService.getShowCmdOutput("show version","overviewshVer");
-        var type = versionInfo.ShowVersion.name;
-	if((type.indexOf("C2960C") !=-1 && type.indexOf("C2960CX") ==-1)|| type.indexOf("CDB") !=-1 || type.indexOf("C2960+") !=-1){
+    var type = versionInfo.ShowVersion.name;
+	if((type.indexOf("C2960C") !=-1 && type.indexOf("C2960CX") ==-1) || type.indexOf("CDB") !=-1 ){
 		MENU_URL="utils/megamenu/helper/menu_CDB_2960L_2960plus.json";
 	}
+	if(type.indexOf("C2960CX") !=-1 || type.indexOf("C2960+") !=-1){
+		MENU_URL="utils/megamenu/helper/menu_2960CX_2960plus.json";
+	}
 	if(type.indexOf("C2960L") !=-1){
 		MENU_URL="utils/megamenu/helper/menu_2960L.json";
 	}
+	if((type.indexOf("C2960X") !=-1 && type.indexOf("C2960XR") ==-1)){
+		MENU_URL="utils/megamenu/helper/menu_2960X.json";
+	}
 	$scope.$on("hideShowMegaMenu", function(event, data){
 		$scope.isActive = data.isActive;
 	});
@@ -56,8 +62,14 @@ function($rootScope, $scope, httpEndPointService, requestRoutingService) {
 			angular.element(event.target).addClass("megamenuCollapsed");
 		}
 	};
+	// Code for detect when routing has changed
+	$scope.$on('$routeChangeStart', function(next, current) {
+		var cTab = angular.element(".submenuTitle").find("a[href='#" + current.$$route.originalPath + "']");
+		expandCollapseMegamenu("a[href='#" + current.$$route.originalPath + "']");
+		angular.element(".menu-item a").parent().parent().removeClass("selectedSubmenu");
+		cTab.parent().parent().addClass("selectedSubmenu");
+	});
 	// Code for Expand and collapse
-
 	var expandTimer = setInterval(function() {
 		expandCollapseMegamenu("a[href='" + location.hash + "']");
 		angular.element(".megamenu-menu").addClass("megamenuCollapsed").each(function(i, menu) {
