@@ -343,7 +343,9 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
 			angular.element(".btnView").show();
 			angular.element(".pageLoader").hide();
         }
-       $scope.loadGridData();
+		$timeout(function(){
+			$scope.loadGridData();
+		},10);
         $scope.isChecked = function (checked, dataItem) {
         	if (!checked) {
                 $scope.countNetFlow = $scope.countNetFlow - 1;
@@ -552,6 +554,8 @@ app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filt
                             netFlowConfigCLI += "collect interface output \n";
                         }
 		        		netFlowConfigCLI += "collect counter bytes long \n";
+		        		netFlowConfigCLI += "collect counter packets long \n";
+		        		netFlowConfigCLI += "collect counter packets perma \n";
 		        		netFlowConfigCLI += "collect timestamp sys-uptime first \n";
 		        		netFlowConfigCLI += "collect timestamp sys-uptime last \n";
 		        		netFlowConfigCLI +=  "exit \n";
